=========
Changelog
=========

Version 0.1.1
=============

- added metadata definition for temporal aggregated products

Version 0.1.0
=============

- setup of first basic metadata class
- supports encoding and decoding of attributes
- support for SAR product metadata
